;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gh" "20260210.1535"
  "Github API client libraries."
  '((emacs   "25.1")
    (pcache  "0.4.2")
    (logito  "0.1")
    (marshal "0.9.0")
    (cl-lib  "0.3"))
  :url "https://github.com/sigma/gh.el"
  :commit "b1551245d3404eac6394abaebe1a9e0b2c504235"
  :revdesc "b1551245d340"
  :authors '(("Yann Hodique" . "yhodique@gmail.com"))
  :maintainers '(("Yann Hodique" . "yhodique@gmail.com")))
